@@ -3,6 +3,8 @@
 
 use crate::build_context::hash_file;
 use anyhow::{bail, Context, Result};
+use base64::engine::general_purpose::STANDARD;
+use base64::Engine;
 use bytesize::ByteSize;
 use configparser::ini::Ini;
 use fs_err as fs;
@@ -490,7 +492,7 @@ pub fn upload(registry: &Registry, wheel_path: &Path) -> Result<(), UploadError>
 
     form.add_stream("content", &wheel, Some(wheel_name), None);
     let multipart_data = form.prepare().map_err(|e| e.error)?;
-    let encoded = base64::encode(format!("{}:{}", registry.username, registry.password));
+    let encoded = STANDARD.encode(format!("{}:{}", registry.username, registry.password));
 
     let agent = http_agent()?;
 
